@@ -52,10 +52,18 @@ class Epidata:
   # Helper function to request and parse epidata
   @staticmethod
   def _request(params):
-    """Request and parse epidata."""
+    """Request and parse epidata.
+
+    We default to GET since it has better caching and logging
+    capabilities, but fall back to POST if the request is too
+    long and returns a 414.
+    """
     try:
       # API call
-      return requests.get(Epidata.BASE_URL, params, headers=_HEADERS).json()
+      req = requests.get(Epidata.BASE_URL, params, headers=_HEADERS)
+      if req.status_code == 414:
+        req = requests.post(Epidata.BASE_URL, params, headers=_HEADERS)
+      return req.json()
     except Exception as e:
       # Something broke
       return {'result': 0, 'message': 'error: ' + str(e)}
@@ -616,3 +624,44 @@ class Epidata:
       params['issues'] = Epidata._list(issues)
     # Make the API call
     return Epidata._request(params)
+
+  # Fetch COVID hospitalization data for specific facilities
+  @staticmethod
+  def covid_hosp_facility(
+      hospital_pks, collection_weeks, publication_dates=None):
+    """Fetch COVID hospitalization data for specific facilities."""
+    # Check parameters
+    if hospital_pks is None or collection_weeks is None:
+      raise Exception('`hospital_pks` and `collection_weeks` are both required')
+    # Set up request
+    params = {
+      'source': 'covid_hosp_facility',
+      'hospital_pks': Epidata._list(hospital_pks),
+      'collection_weeks': Epidata._list(collection_weeks),
+    }
+    if publication_dates is not None:
+      params['publication_dates'] = Epidata._list(publication_dates)
+    # Make the API call
+    return Epidata._request(params)
+
+  # Lookup COVID hospitalization facility identifiers
+  @staticmethod
+  def covid_hosp_facility_lookup(
+      state=None, ccn=None, city=None, zip=None, fips_code=None):
+    """Lookup COVID hospitalization facility identifiers."""
+    # Set up request
+    params = {'source': 'covid_hosp_facility_lookup'}
+    if state is not None:
+      params['state'] = state
+    elif ccn is not None:
+      params['ccn'] = ccn
+    elif city is not None:
+      params['city'] = city
+    elif zip is not None:
+      params['zip'] = zip
+    elif fips_code is not None:
+      params['fips_code'] = fips_code
+    else:
+      raise Exception('one of `state`, `ccn`, `city`, `zip`, or `fips_code` is required')
+    # Make the API call
+    return Epidata._request(params)
